# Code to generate six different phylomorphospaces using the Claddis package
# NB: Is *very* slow due to the ancestral state estimation steps - don't expect it to run quickly

# Types:
# PCO1 - pre-OASE1; Maintains missing data and polymorphisms
# PCO3 - pre-OASE2; Collapses polymorphisms
# PCO2 - pre-OASE3; Estimates states for every character at internal nodes
# PCO4 - pre-OASE4; Collapses polymorphisms at tips and estimates states for every character at both internal and terminal nodes (no missing values left)
# PCO5 - post-OASE; Maintains missing data and polymorphisms for ordination and then estimates ancestral ordination values directly from ordination axes
# PCO6 - "phylospace"; Uses phylogenetic distances as input data (no morphology at all)

# Get in required libraries (these must be installed prior to running the script):
library(ade4)
library(paleotree)
library(phytools)
library(strap)
library(gdata)
library(Claddis)
library(viridis)

# Set working directory (this must point to the folder containing the input files on your own machine):
setwd("[filepath to folder containing data files on your personal machine]")

# Read in cladistic matrix:
clad.matrix <- ReadMorphNexus("Brusatte_etal_2014.nex")

# Read in tip ages:
tip.ages <- read.table("ages.txt", sep = "\t", header = FALSE, row.names = 1)
colnames(tip.ages) <- c("FAD", "LAD")

# List wildcards, Cenozoic and redundant outgroup taxa (for removal):
taxa.to.remove <- c("Kinnareemimus", "Epidendrosaurus", "Pyroraptor_olympius", "Hesperonychus_elizabethae", "Limenavis_patagonica", "Lithornis", "Crypturellus_undulatus", "Gallus_gallus", "Crax_pauxi", "Anas_platyrhynchus", "Chauna_torquata", "Sinraptor_dongi")

# Read in sampled trees:
trees <- read.tree("sampled.tre")

# Isolate first sampled tree only:
tree <- trees[[1]]

# Remove wildcards (etc.) taxa from tip ages:
tip.ages <- tip.ages[-match(taxa.to.remove, rownames(tip.ages)), ]

# Remove wildcards (etc.) taxa from matrix:
clad.matrix$matrix <- clad.matrix$matrix[-match(taxa.to.remove, rownames(clad.matrix$matrix)), ]

# Set number of replicates for randomly sampling tip ages (not used right now):
nrep <- 1

# Create matrix to store randomly sampled tip ages:
rand.tip.ages <- matrix(0, nrow = nrow(tip.ages), ncol = nrep)

# Randomly sample tip ages:
for(i in 1:length(tip.ages[, 1])) rand.tip.ages[i,] <- runif(nrep, max = tip.ages[i, 1], min = tip.ages[i, 2])

# Replicate number - placeholder for a loop not used:
i <- 1

# Get starting tip age matrix for replicate:
rep.tip.ages <- tip.ages

# Use ith randomly sampled tip ages:
rep.tip.ages[, 1] <- rep.tip.ages[, 2] <- rand.tip.ages[, i]

# Time-scale tree (vartime based on one stage older than oldest taxon):
tree <- timePaleoPhy(tree, timeData = rep.tip.ages, "equal", vartime = 2)

# Estimate ancestors for nodes that connect to known tip values only:
ancs1 <- AncStateEstMatrix(clad.matrix, tree, estimate.allchars = FALSE, estimate.tips = FALSE)

# Estimate ancestors for all nodes by setting missing tips as equal prior on all states (instead of pruning):
ancs2 <- AncStateEstMatrix(clad.matrix, tree, estimate.allchars = TRUE, estimate.tips = FALSE)

# Estimate tips as well as ancestors, but only using tip values with known values (effectively only collapses polymorphisms):
ancs3 <- AncStateEstMatrix(clad.matrix, tree, estimate.allchars = FALSE, estimate.tips = TRUE)

# Estimate all nodes and tips - uses known tip values mixed with equal priors for all states on unknown values and fills in all gaps:
ancs4 <- AncStateEstMatrix(clad.matrix, tree, estimate.allchars = TRUE, estimate.tips = TRUE)

# Create separate matrices for ancestral estimation types:
matrix1 <- matrix2 <- matrix3 <- matrix4 <- matrix5 <- clad.matrix

# Add ancestors into matrices:
matrix1$matrix <- rbind(matrix1$matrix, ancs1)
matrix2$matrix <- rbind(matrix2$matrix, ancs2)
matrix3$matrix <- ancs3
matrix4$matrix <- ancs4

# Get morphological distances for matrices:
dist1 <- MorphDistMatrix(matrix1, transform.proportional.distances = "arcsine_sqrt")
dist2 <- MorphDistMatrix(matrix2, transform.proportional.distances = "arcsine_sqrt")
dist3 <- MorphDistMatrix(matrix3, transform.proportional.distances = "arcsine_sqrt")
dist4 <- MorphDistMatrix(matrix4, transform.proportional.distances = "arcsine_sqrt")

# Phylomorphospace distances (starter):
dist5 <- MorphDistMatrix(clad.matrix, transform.proportional.distances = "arcsine_sqrt")

# Trim morphological distances for ancestors and trees:
trim1 <- TrimMorphDistMatrix(dist1$max.dist.matrix, tree = tree)
trim2 <- TrimMorphDistMatrix(dist2$max.dist.matrix, tree = tree)
trim3 <- TrimMorphDistMatrix(dist3$max.dist.matrix, tree = tree)
trim4 <- TrimMorphDistMatrix(dist4$max.dist.matrix, tree = tree)

# Trim phylomorphospace distances (will have to trim tree separately):
trim5 <- TrimMorphDistMatrix(dist5$max.dist.matrix)

# Overwrite distance matrices with trimmed versions:
dist1 <- trim1$dist.matrix
dist2 <- trim2$dist.matrix
dist3 <- trim3$dist.matrix
dist4 <- trim4$dist.matrix
dist5 <- trim5$dist.matrix

# Get phylogenetic distances:
dist6 <- dist.nodes(tree)

# Add taxa to phylogenetic distances:
rownames(dist6)[1:Ntip(tree)] <- colnames(dist6)[1:Ntip(tree)] <- tree$tip.label

# Isolate trimmed trees:
tree1 <- trim1$tree
tree2 <- trim2$tree
tree3 <- trim3$tree
tree4 <- trim4$tree

# Trim tree for phylomorphospace distances:
tree5 <- drop.tip(tree, setdiff(tree$tip.label, rownames(dist5)))

# Set tree6 as just the raw tree (no taxa dropped):
tree6 <- tree

# Ordinated ancestral estimation data using PCO:
pco1 <- cmdscale(dist1, k = Ntip(tree1) - 1, add = TRUE)$points
pco2 <- cmdscale(dist2, k = Ntip(tree2) - 1, add = TRUE)$points
pco3 <- cmdscale(dist3, k = Ntip(tree3) - 1, add = TRUE)$points
pco4 <- cmdscale(dist4, k = Ntip(tree4) - 1, add = TRUE)$points
pco5 <- cmdscale(dist5, k = nrow(dist5) - 1, add = TRUE)$points

# Create ancestors matrix for post-ordination estimates:
ancs5 <- matrix(rep(NA, Nnode(tree5) * ncol(pco5)), nrow = Nnode(tree5))

# Get post-ordination ancestral estimates:
for(j in 1:ncol(pco5)) ancs5[, j] <- ace(pco5[, j], tree5)$ace

# Add rownames to ancestors:
rownames(ancs5) <- names(ace(pco5[, 1], tree5)$ace)

# Add ancestors to tip values:
pco5 <- rbind(pco5, ancs5)

# Ordiante phylogenetic distances:
pco6 <- cmdscale(dist6, k = Ntip(tree) - 1, add = TRUE)$points

# Get distacne from root data:
rootdist1 <- as.matrix(dist(pco1, diag = TRUE, upper = TRUE))[, (Ntip(tree1) + 1)]
rootdist2 <- as.matrix(dist(pco2, diag = TRUE, upper = TRUE))[, (Ntip(tree2) + 1)]
rootdist3 <- as.matrix(dist(pco3, diag = TRUE, upper = TRUE))[, (Ntip(tree3) + 1)]
rootdist4 <- as.matrix(dist(pco4, diag = TRUE, upper = TRUE))[, (Ntip(tree4) + 1)]
rootdist5 <- as.matrix(dist(pco5, diag = TRUE, upper = TRUE))[, (Ntip(tree5) + 1)]
rootdist6 <- as.matrix(dist(pco6, diag = TRUE, upper = TRUE))[, (Ntip(tree6) + 1)]

# Get node ages:
nodeages1 <- GetNodeAges(tree1)
nodeages2 <- GetNodeAges(tree2)
nodeages3 <- GetNodeAges(tree3)
nodeages4 <- GetNodeAges(tree4)
nodeages5 <- GetNodeAges(tree5)
nodeages6 <- GetNodeAges(tree6)

# Add tip names:
names(nodeages1)[1:Ntip(tree1)] <- tree1$tip.label
names(nodeages2)[1:Ntip(tree2)] <- tree2$tip.label
names(nodeages3)[1:Ntip(tree3)] <- tree3$tip.label
names(nodeages4)[1:Ntip(tree4)] <- tree4$tip.label
names(nodeages5)[1:Ntip(tree5)] <- tree5$tip.label
names(nodeages6)[1:Ntip(tree6)] <- tree6$tip.label

# Create matrix to store branch slopes for ordination 1:
branchslopes1 <- matrix(0, nrow = nrow(tree1$edge), ncol = 3)

# Get branch slopes for ordination 1:
for(j in 1:nrow(tree1$edge)) {
		nodes <- tree1$edge[j, ]
    if(any(nodes <= Ntip(tree1))) nodes[nodes <= Ntip(tree1)] <- tree1$tip.label[nodes[nodes <= Ntip(tree1)]]
    branchslopes1[j, ] <- c(nodeages1[nodes], abs(diff(rootdist1[nodes])) / abs(diff(nodeages1[nodes])))
}

# Create matrix to store branch slopes for ordination 2:
branchslopes2 <- matrix(0, nrow = nrow(tree2$edge), ncol = 3)

# Get branch slopes for ordination 2:
for(j in 1:nrow(tree2$edge)) {
		nodes <- tree2$edge[j, ]
    if(any(nodes <= Ntip(tree2))) nodes[nodes <= Ntip(tree2)] <- tree2$tip.label[nodes[nodes <= Ntip(tree2)]]
    branchslopes2[j, ] <- c(nodeages2[nodes], abs(diff(rootdist2[nodes])) / abs(diff(nodeages2[nodes])))
}

# Create matrix to store branch slopes for ordination 3:
branchslopes3 <- matrix(0, nrow = nrow(tree3$edge), ncol = 3)

# Get branch slopes for ordination 3:
for(j in 1:nrow(tree3$edge)) {
		nodes <- tree3$edge[j, ]
    if(any(nodes <= Ntip(tree3))) nodes[nodes <= Ntip(tree3)] <- tree3$tip.label[nodes[nodes <= Ntip(tree3)]]
    branchslopes3[j, ] <- c(nodeages3[nodes], abs(diff(rootdist3[nodes])) / abs(diff(nodeages3[nodes])))
}

# Create matrix to store branch slopes for ordination 4:
branchslopes4 <- matrix(0, nrow = nrow(tree4$edge), ncol = 3)

# Get branch slopes for ordination 4:
for(j in 1:nrow(tree4$edge)) {
		nodes <- tree4$edge[j, ]
    if(any(nodes <= Ntip(tree4))) nodes[nodes <= Ntip(tree4)] <- tree4$tip.label[nodes[nodes <= Ntip(tree4)]]
    branchslopes4[j, ] <- c(nodeages4[nodes], abs(diff(rootdist4[nodes])) / abs(diff(nodeages4[nodes])))
}

# Create matrix to store branch slopes for ordination 5:
branchslopes5 <- matrix(0, nrow = nrow(tree5$edge), ncol = 3)

# Get branch slopes for ordination 5:
for(j in 1:nrow(tree5$edge)) {
		nodes <- tree5$edge[j, ]
    if(any(nodes <= Ntip(tree5))) nodes[nodes <= Ntip(tree5)] <- tree5$tip.label[nodes[nodes <= Ntip(tree5)]]
    branchslopes5[j, ] <- c(nodeages5[nodes], abs(diff(rootdist5[nodes])) / abs(diff(nodeages5[nodes])))
}

# Create matrix to store branch slopes for ordination 6:
branchslopes6 <- matrix(0, nrow = nrow(tree6$edge), ncol = 3)

# Get branch slopes for ordination 6:
for(j in 1:nrow(tree6$edge)) {
		nodes <- tree6$edge[j, ]
    if(any(nodes <= Ntip(tree6))) nodes[nodes <= Ntip(tree6)] <- tree6$tip.label[nodes[nodes <= Ntip(tree6)]]
    branchslopes6[j, ] <- c(nodeages6[nodes], abs(diff(rootdist6[nodes])) / abs(diff(nodeages6[nodes])))
}

# Create time bins for branch slopes:
tbins1 <- seq(max(branchslopes1[, 1]), min(branchslopes1[, 1]), length.out = 100)
tbins2 <- seq(max(branchslopes2[, 1]), min(branchslopes2[, 1]), length.out = 100)
tbins3 <- seq(max(branchslopes3[, 1]), min(branchslopes3[, 1]), length.out = 100)
tbins4 <- seq(max(branchslopes4[, 1]), min(branchslopes4[, 1]), length.out = 100)
tbins5 <- seq(max(branchslopes5[, 1]), min(branchslopes5[, 1]), length.out = 100)
tbins6 <- seq(max(branchslopes6[, 1]), min(branchslopes6[, 1]), length.out = 100)

# Create matrix of slopes by bin:
binslopes1 <- binslopes2 <- binslopes3 <- binslopes4 <- binslopes5 <- binslopes6 <- matrix(nrow = 99, ncol = 2)

# Get bin slopes:
for(j in 2:length(tbins1)) {
		branchesinbin <- intersect(which(branchslopes1[, 1] >= tbins1[j]), which(branchslopes1[, 2] <= tbins1[(j - 1)]))
    binslopes1[(j - 1), 1] <- mean(log(branchslopes1[branchesinbin, 3]))
    binslopes1[(j - 1), 2] <- sd(log(branchslopes1[branchesinbin, 3])) * 1.96
}
for(j in 2:length(tbins2)) {
		branchesinbin <- intersect(which(branchslopes2[, 1] >= tbins2[j]), which(branchslopes2[, 2] <= tbins2[(j - 1)]))
    binslopes2[(j - 1), 1] <- mean(log(branchslopes2[branchesinbin, 3]))
    binslopes2[(j - 1), 2] <- sd(log(branchslopes2[branchesinbin, 3])) * 1.96
}
for(j in 2:length(tbins3)) {
		branchesinbin <- intersect(which(branchslopes3[, 1] >= tbins3[j]), which(branchslopes3[, 2] <= tbins3[(j - 1)]))
    binslopes3[(j - 1), 1] <- mean(log(branchslopes3[branchesinbin, 3]))
    binslopes3[(j - 1), 2] <- sd(log(branchslopes3[branchesinbin, 3])) * 1.96
}
for(j in 2:length(tbins4)) {
		branchesinbin <- intersect(which(branchslopes4[, 1] >= tbins4[j]), which(branchslopes4[, 2] <= tbins4[(j - 1)]))
    binslopes4[(j - 1), 1] <- mean(log(branchslopes4[branchesinbin, 3]))
    binslopes4[(j - 1), 2] <- sd(log(branchslopes4[branchesinbin, 3])) * 1.96
}
for(j in 2:length(tbins5)) {
		branchesinbin <- intersect(which(branchslopes5[, 1] >= tbins5[j]), which(branchslopes5[, 2] <= tbins5[(j - 1)]))
    binslopes5[(j - 1), 1] <- mean(log(branchslopes5[branchesinbin, 3]))
    binslopes5[(j - 1), 2] <- sd(log(branchslopes5[branchesinbin, 3])) * 1.96
}
for(j in 2:length(tbins6)) {
		branchesinbin <- intersect(which(branchslopes6[, 1] >= tbins6[j]), which(branchslopes6[, 2] <= tbins6[(j - 1)]))
    binslopes6[(j - 1), 1] <- mean(log(branchslopes6[branchesinbin, 3]))
    binslopes6[(j - 1), 2] <- sd(log(branchslopes6[branchesinbin, 3])) * 1.96
}

# Begin to output data to PDF:
pdf(paste("output_", i, ".pdf", sep = ""), useDingbats = FALSE)

# Set axes to plot:
pco_axis_1 <- 1
pco_axis_2 <- 2

# Plot PCO 1:
plot(pco1[, pco_axis_1], pco1[, pco_axis_2], type = "n", xlab = paste("PCO ", pco_axis_1, " (", round(var(pco1[, pco_axis_1]) / sum(apply(pco1, 2, var)) * 100, 2), "% variance explained)", sep = ""), ylab = paste("PCO ", pco_axis_2, " (", round(var(pco1[, pco_axis_2]) / sum(apply(pco1, 2, var)) * 100, 2), "% variance explained)", sep = ""), main = "Ordination 1")
for(j in 1:nrow(tree1$edge)) {
		nodes <- tree1$edge[j, ]
    if(any(nodes <= Ntip(tree1))) nodes[nodes <= Ntip(tree1)] <- tree1$tip.label[nodes[nodes <= Ntip(tree1)]]
    lines(x = c(pco1[nodes[1], pco_axis_1], pco1[nodes[2], pco_axis_1]), y = c(pco1[nodes[1], pco_axis_2], pco1[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco1[, pco_axis_1], pco1[, pco_axis_2], pch = 20, col = "red")

# Plot PCO 3 - actually analysis 2!:
plot(pco3[, pco_axis_1], pco3[, pco_axis_2], type = "n", xlab = paste("PCO ", pco_axis_1, " (", round(var(pco3[, pco_axis_1]) / sum(apply(pco3, 2, var)) * 100, 2), "% variance explained)", sep = ""), ylab = paste("PCO ", pco_axis_2, " (", round(var(pco3[, pco_axis_2]) / sum(apply(pco3, 2, var)) * 100, 2), "% variance explained)", sep = ""), main = "Ordination 2")
for(j in 1:nrow(tree3$edge)) {
		nodes <- tree3$edge[j, ]
    if(any(nodes <= Ntip(tree3))) nodes[nodes <= Ntip(tree3)] <- tree3$tip.label[nodes[nodes <= Ntip(tree3)]]
    lines(x = c(pco3[nodes[1], pco_axis_1], pco3[nodes[2], pco_axis_1]), y = c(pco3[nodes[1], pco_axis_2], pco3[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco3[, pco_axis_1], pco3[, pco_axis_2], pch = 20, col = "red")

# Plot PCO 2 - actually analysis 3:
plot(pco2[, pco_axis_1], pco2[, pco_axis_2], type = "n", xlab = paste("PCO ", pco_axis_1, " (", round(var(pco2[, pco_axis_1]) / sum(apply(pco2, 2, var)) * 100, 2), "% variance explained)", sep = ""), ylab = paste("PCO ", pco_axis_2, " (", round(var(pco2[, pco_axis_2]) / sum(apply(pco2, 2, var)) * 100, 2), "% variance explained)", sep = ""), main = "Ordination 3")
for(j in 1:nrow(tree2$edge)) {
		nodes <- tree2$edge[j, ]
    if(any(nodes <= Ntip(tree2))) nodes[nodes <= Ntip(tree2)] <- tree2$tip.label[nodes[nodes <= Ntip(tree2)]]
    lines(x = c(pco2[nodes[1], pco_axis_1], pco2[nodes[2], pco_axis_1]), y = c(pco2[nodes[1], pco_axis_2], pco2[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco2[, pco_axis_1], pco2[, pco_axis_2], pch = 20, col = "red")

# Plot PCO 4:
plot(pco4[, pco_axis_1], pco4[, pco_axis_2], type = "n", xlab = paste("PCO ", pco_axis_1, " (", round(var(pco4[, pco_axis_1]) / sum(apply(pco4, 2, var)) * 100, 2), "% variance explained)", sep = ""), ylab = paste("PCO ", pco_axis_2, " (", round(var(pco4[, pco_axis_2]) / sum(apply(pco4, 2, var)) * 100, 2), "% variance explained)", sep = ""), main = "Ordination 4")
for(j in 1:nrow(tree4$edge)) {
		nodes <- tree4$edge[j, ]
    if(any(nodes <= Ntip(tree4))) nodes[nodes <= Ntip(tree4)] <- tree4$tip.label[nodes[nodes <= Ntip(tree4)]]
    lines(x = c(pco4[nodes[1], pco_axis_1], pco4[nodes[2], pco_axis_1]), y = c(pco4[nodes[1], pco_axis_2], pco4[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco4[, pco_axis_1], pco4[, pco_axis_2], pch = 20, col = "red")

# Plot PCO 5:
plot(pco5[, pco_axis_1], pco5[, pco_axis_2], type = "n", xlab = paste("PCO ", pco_axis_1, " (", round(var(pco5[, pco_axis_1]) / sum(apply(pco5, 2, var)) * 100, 2), "% variance explained)", sep = ""), ylab = paste("PCO ", pco_axis_2, " (", round(var(pco5[, pco_axis_2]) / sum(apply(pco5, 2, var)) * 100, 2), "% variance explained)", sep = ""), main = "Ordination 5")
for(j in 1:nrow(tree5$edge)) {
		nodes <- tree5$edge[j, ]
    if(any(nodes <= Ntip(tree5))) nodes[nodes <= Ntip(tree5)] <- tree5$tip.label[nodes[nodes <= Ntip(tree5)]]
    lines(x = c(pco5[nodes[1], pco_axis_1], pco5[nodes[2], pco_axis_1]), y = c(pco5[nodes[1], pco_axis_2], pco5[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco5[, pco_axis_1], pco5[, pco_axis_2], pch = 20, col = "red")

# Plot PCO 6:
plot(pco6[, pco_axis_1], pco6[, pco_axis_2], type = "n", xlab = paste("PCO ", pco_axis_1, " (", round(var(pco6[, pco_axis_1]) / sum(apply(pco6, 2, var)) * 100, 2), "% variance explained)", sep = ""), ylab = paste("PCO ", pco_axis_2, " (", round(var(pco6[, pco_axis_2]) / sum(apply(pco6, 2, var)) * 100, 2), "% variance explained)", sep = ""), main = "Ordination 6")
for(j in 1:nrow(tree6$edge)) {
		nodes <- tree6$edge[j, ]
    if(any(nodes <= Ntip(tree6))) nodes[nodes <= Ntip(tree6)] <- tree6$tip.label[nodes[nodes <= Ntip(tree6)]]
    lines(x = c(pco6[nodes[1], pco_axis_1], pco6[nodes[2], pco_axis_1]), y = c(pco6[nodes[1], pco_axis_2], pco6[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco6[, pco_axis_1], pco6[, pco_axis_2], pch = 20, col = "red")

# Plot distance from root 1::
plot(nodeages1, rootdist1[c(tree1$tip.label, (Ntip(tree1) + 1):(Ntip(tree1) + Nnode(tree1)))], type = "n", ylab = "Distance from root", xlab = "Time (Ma)", xlim = rev(range(nodeages6)), main = "Root distance 1")
for(j in 1:nrow(tree1$edge)) {
		nodes <- tree1$edge[j, ]
    if(any(nodes <= Ntip(tree1))) nodes[nodes <= Ntip(tree1)] <- tree1$tip.label[nodes[nodes <= Ntip(tree1)]]
    lines(x = nodeages1[nodes], y = rootdist1[nodes], col = "black")
}

# Plot distance from root 2:
plot(nodeages3, rootdist3[c(tree3$tip.label, (Ntip(tree3) + 1):(Ntip(tree3) + Nnode(tree3)))], type = "n", ylab = "Distance from root", xlab = "Time (Ma)", xlim = rev(range(nodeages6)), main = "Root distance 2")
for(j in 1:nrow(tree3$edge)) {
		nodes <- tree3$edge[j, ]
    if(any(nodes <= Ntip(tree3))) nodes[nodes <= Ntip(tree3)] <- tree3$tip.label[nodes[nodes <= Ntip(tree3)]]
    lines(x = nodeages3[nodes], y = rootdist3[nodes], col = "black")
}

# Plot distance from root 3:
plot(nodeages2, rootdist2[c(tree2$tip.label, (Ntip(tree2) + 1):(Ntip(tree2) + Nnode(tree2)))], type = "n", ylab = "Distance from root", xlab = "Time (Ma)", xlim = rev(range(nodeages6)), main = "Root distance 3")
for(j in 1:nrow(tree2$edge)) {
		nodes <- tree2$edge[j, ]
    if(any(nodes <= Ntip(tree2))) nodes[nodes <= Ntip(tree2)] <- tree2$tip.label[nodes[nodes <= Ntip(tree2)]]
    lines(x = nodeages2[nodes], y = rootdist2[nodes], col = "black")
}

# Plot distance from root 4:
plot(nodeages4, rootdist4[c(tree4$tip.label, (Ntip(tree4) + 1):(Ntip(tree4) + Nnode(tree4)))], type = "n", ylab = "Distance from root", xlab = "Time (Ma)", xlim = rev(range(nodeages6)), main = "Root distance 4")
for(j in 1:nrow(tree4$edge)) {
		nodes <- tree4$edge[j, ]
    if(any(nodes <= Ntip(tree4))) nodes[nodes <= Ntip(tree4)] <- tree4$tip.label[nodes[nodes <= Ntip(tree4)]]
    lines(x = nodeages4[nodes], y = rootdist4[nodes], col = "black")
}

# Plot distance from root 5:
plot(nodeages5, rootdist5[c(tree5$tip.label, (Ntip(tree5) + 1):(Ntip(tree5) + Nnode(tree5)))], type = "n", ylab = "Distance from root", xlab = "Time (Ma)", xlim = rev(range(nodeages6)), main = "Root distance 5")
for(j in 1:nrow(tree5$edge)) {
		nodes <- tree5$edge[j, ]
    if(any(nodes <= Ntip(tree5))) nodes[nodes <= Ntip(tree5)] <- tree5$tip.label[nodes[nodes <= Ntip(tree5)]]
    lines(x = nodeages5[nodes], y = rootdist5[nodes], col = "black")
}

# Plot distance from root 6:
plot(nodeages6, rootdist6[c(tree6$tip.label, (Ntip(tree6) + 1):(Ntip(tree6) + Nnode(tree6)))], type = "n", ylab = "Distance from root", xlab = "Time (Ma)", xlim = rev(range(nodeages6)), main = "Root distance 6")
for(j in 1:nrow(tree6$edge)) {
		nodes <- tree6$edge[j, ]
    if(any(nodes <= Ntip(tree6))) nodes[nodes <= Ntip(tree6)] <- tree6$tip.label[nodes[nodes <= Ntip(tree6)]]
    lines(x = nodeages6[nodes], y = rootdist6[nodes], col = "black")
}

# Plot distance from root rates 1:
plot(tbins1[1:99] + (diff(tbins1) / 2), binslopes1[, 1], type = "n", xlab = "Time (Ma)", ylab = "Mean log absolute branch slope", xlim = rev(range(nodeages6)), ylim = c(min(binslopes1[, 1] - binslopes1[, 2]), max(binslopes1[, 1] + binslopes1[, 2])), main = "Implied rates 1")
polygon(c(tbins1[1:99] + (diff(tbins1) / 2), rev(tbins1[1:99] + (diff(tbins1) / 2))), c((binslopes1[, 1] + binslopes1[, 2]), rev(binslopes1[, 1] - binslopes1[, 2])), border = 0, col = "grey")
points(tbins1[1:99] + (diff(tbins1) / 2), binslopes1[, 1], type = "l", lwd = 2)

# Plot distance from root rates 2:
plot(tbins3[1:99] + (diff(tbins3) / 2), binslopes3[, 1], type = "n", xlab = "Time (Ma)", ylab = "Mean log absolute branch slope", xlim = rev(range(nodeages6)), ylim = c(min(binslopes3[, 1] - binslopes3[, 2]), max(binslopes3[, 1] + binslopes3[, 2])), main = "Implied rates 2")
polygon(c(tbins3[1:99] + (diff(tbins3) / 2), rev(tbins3[1:99] + (diff(tbins3) / 2))), c((binslopes3[, 1] + binslopes3[, 2]), rev(binslopes3[, 1] - binslopes3[, 2])), border = 0, col = "grey")
points(tbins3[1:99] + (diff(tbins3) / 2), binslopes3[, 1], type = "l", lwd = 2)

# Plot distance from root rates 3:
plot(tbins2[1:99] + (diff(tbins2) / 2), binslopes2[, 1], type = "n", xlab = "Time (Ma)", ylab = "Mean log absolute branch slope", xlim = rev(range(nodeages6)), ylim = c(min(binslopes2[, 1] - binslopes2[, 2]), max(binslopes2[, 1] + binslopes2[, 2])), main = "Implied rates 3")
polygon(c(tbins2[1:99] + (diff(tbins2) / 2), rev(tbins2[1:99] + (diff(tbins2) / 2))), c((binslopes2[, 1] + binslopes2[, 2]), rev(binslopes2[, 1] - binslopes2[, 2])), border = 0, col = "grey")
points(tbins2[1:99] + (diff(tbins2) / 2), binslopes2[, 1], type = "l", lwd = 2)

# Plot distance from root rates 4:
plot(tbins4[1:99] + (diff(tbins4) / 2), binslopes4[, 1], type = "n", xlab = "Time (Ma)", ylab = "Mean log absolute branch slope", xlim = rev(range(nodeages6)), ylim = c(min(binslopes4[, 1] - binslopes4[, 2]), max(binslopes4[, 1] + binslopes4[, 2])), main = "Implied rates 4")
polygon(c(tbins4[1:99] + (diff(tbins4) / 2), rev(tbins4[1:99] + (diff(tbins4) / 2))), c((binslopes4[, 1] + binslopes4[, 2]), rev(binslopes4[, 1] - binslopes4[, 2])), border = 0, col = "grey")
points(tbins4[1:99] + (diff(tbins4) / 2), binslopes4[, 1], type = "l", lwd = 2)

# Plot distance from root rates 5:
plot(tbins5[1:99] + (diff(tbins5) / 2), binslopes5[, 1], type = "n", xlab = "Time (Ma)", ylab = "Mean log absolute branch slope", xlim = rev(range(nodeages6)), ylim = c(min(binslopes5[, 1] - binslopes5[, 2]), max(binslopes5[, 1] + binslopes5[, 2])), main = "Implied rates 5")
polygon(c(tbins5[1:99] + (diff(tbins5) / 2), rev(tbins5[1:99] + (diff(tbins5) / 2))), c((binslopes5[, 1] + binslopes5[, 2]), rev(binslopes5[, 1] - binslopes5[, 2])), border = 0, col = "grey")
points(tbins5[1:99] + (diff(tbins5) / 2), binslopes5[, 1], type = "l", lwd = 2)

# Plot distance from root rates 6:
plot(tbins6[1:99] + (diff(tbins6) / 2), binslopes6[, 1], type = "n", xlab = "Time (Ma)", ylab = "Mean log absolute branch slope", xlim = rev(range(nodeages6)), ylim = c(min(binslopes6[, 1] - binslopes6[, 2]), max(binslopes6[, 1] + binslopes6[, 2])), main = "Implied rates 6")
polygon(c(tbins6[1:99] + (diff(tbins6) / 2), rev(tbins6[1:99] + (diff(tbins6) / 2))), c((binslopes6[, 1] + binslopes6[, 2]), rev(binslopes6[, 1] - binslopes6[, 2])), border = 0, col = "grey")
points(tbins6[1:99] + (diff(tbins6) / 2), binslopes6[, 1], type = "l", lwd = 2)

# Correlations between phylogenetic and morphological distances:
#mantel.rtest(dist(pco1), as.dist(dist.nodes(tree1)), nrepet = 10000)
#mantel.rtest(dist(pco3), as.dist(dist.nodes(tree3)), nrepet = 10000)
#mantel.rtest(dist(pco2), as.dist(dist.nodes(tree2)), nrepet = 10000)
#mantel.rtest(dist(pco4), as.dist(dist.nodes(tree4)), nrepet = 10000)
#mantel.rtest(dist(pco5), as.dist(dist.nodes(tree5)), nrepet = 10000)
#mantel.rtest(dist(pco6), as.dist(dist.nodes(tree6)), nrepet = 10000)

# Distance from root rate correlations:
cor.test(x = binslopes6[, 1], y = binslopes1[, 1], method = "kendall")$estimate
cor.test(x = binslopes6[, 1], y = binslopes3[, 1], method = "kendall")$estimate
cor.test(x = binslopes6[, 1], y = binslopes2[, 1], method = "kendall")$estimate
cor.test(x = binslopes6[, 1], y = binslopes4[, 1], method = "kendall")$estimate
cor.test(x = binslopes6[, 1], y = binslopes5[, 1], method = "kendall")$estimate
cor.test(x = binslopes6[, 1], y = binslopes6[, 1], method = "kendall")$estimate

# Plot scree plots:
plot(1:ncol(pco1), apply(pco1, 2, var) / sum(apply(pco1, 2, var)) * 100, type = "l", xlab = "PCO Axis", ylab = "Percentage variance explained", main = "Scree 1")
plot(1:ncol(pco3), apply(pco3, 2, var) / sum(apply(pco3, 2, var)) * 100, type = "l", xlab = "PCO Axis", ylab = "Percentage variance explained", main = "Scree 2")
plot(1:ncol(pco2), apply(pco2, 2, var) / sum(apply(pco2, 2, var)) * 100, type = "l", xlab = "PCO Axis", ylab = "Percentage variance explained", main = "Scree 3")
plot(1:ncol(pco4), apply(pco4, 2, var) / sum(apply(pco4, 2, var)) * 100, type = "l", xlab = "PCO Axis", ylab = "Percentage variance explained", main = "Scree 4")
plot(1:ncol(pco5), apply(pco5[1:Ntip(tree5), ], 2, var) / sum(apply(pco5[1:Ntip(tree5), ], 2, var)) * 100, type = "l", xlab = "PCO Axis", ylab = "Percentage variance explained", main = "Scree 5")
plot(1:ncol(pco6), apply(pco6, 2, var) / sum(apply(pco6, 2, var)) * 100, type = "l", xlab = "PCO Axis", ylab = "Percentage variance explained", main = "Scree 6")

# Plot cumulative variance percentage on single plot:
plot(x = 1:ncol(pco1) / ncol(pco1), y = cumsum(apply(pco1, 2, var) / sum(apply(pco1, 2, var))), type = "l", xlab = "Proportional ordination axes", ylab = "Cumulative percent variance explained", col = rgb(0, 1, 1, 1), lwd = 3)
points(x = 1:ncol(pco3) / ncol(pco3), y = cumsum(apply(pco3, 2, var) / sum(apply(pco3, 2, var))), type = "l", col = rgb(1, 1, 0, 1), lwd = 3)
points(x = 1:ncol(pco2) / ncol(pco2), y = cumsum(apply(pco2, 2, var) / sum(apply(pco2, 2, var))), type = "l", col = rgb(1, 0, 0, 1), lwd = 3)
points(x = 1:ncol(pco4) / ncol(pco4), y = cumsum(apply(pco4, 2, var) / sum(apply(pco4, 2, var))), type = "l", col = rgb(0, 1, 0, 1), lwd = 3)
points(x = 1:ncol(pco5) / ncol(pco5), y = cumsum(apply(pco5, 2, var) / sum(apply(pco5, 2, var))), type = "l", col = rgb(0, 0, 1, 1), lwd = 3)
points(x = 1:ncol(pco6) / ncol(pco6), y = cumsum(apply(pco6, 2, var) / sum(apply(pco6, 2, var))), type = "l", col = rgb(1, 0, 1, 1), lwd = 3)
legend(x = 0, y = 1, legend = c("Pre-OASE1", "Pre-OASE2", "Pre-OASE3", "Pre-OASE4", "Post-OASE", "Phylospace"), col = c(rgb(0, 1, 1, 1), rgb(1, 1, 0, 1), rgb(1, 0, 0, 1), rgb(0, 1, 0, 1), rgb(0, 0, 1, 1), rgb(1, 0, 1, 1)), lwd = 3)

# Calculate normalised scree values:
Scree1 <- ((apply(pco1, 2, var) / sum(apply(pco1, 2, var))) - min(apply(pco1, 2, var) / sum(apply(pco1, 2, var)))) / max((apply(pco1, 2, var) / sum(apply(pco1, 2, var))) - min(apply(pco1, 2, var) / sum(apply(pco1, 2, var))))
Scree2 <- ((apply(pco2, 2, var) / sum(apply(pco2, 2, var))) - min(apply(pco2, 2, var) / sum(apply(pco2, 2, var)))) / max((apply(pco2, 2, var) / sum(apply(pco2, 2, var))) - min(apply(pco2, 2, var) / sum(apply(pco2, 2, var))))
Scree3 <- ((apply(pco3, 2, var) / sum(apply(pco3, 2, var))) - min(apply(pco3, 2, var) / sum(apply(pco3, 2, var)))) / max((apply(pco3, 2, var) / sum(apply(pco3, 2, var))) - min(apply(pco3, 2, var) / sum(apply(pco3, 2, var))))
Scree4 <- ((apply(pco4, 2, var) / sum(apply(pco4, 2, var))) - min(apply(pco4, 2, var) / sum(apply(pco4, 2, var)))) / max((apply(pco4, 2, var) / sum(apply(pco4, 2, var))) - min(apply(pco4, 2, var) / sum(apply(pco4, 2, var))))
Scree5 <- ((apply(pco5[tree5$tip.label, ], 2, var) / sum(apply(pco5[tree5$tip.label, ], 2, var))) - min(apply(pco5[tree5$tip.label, ], 2, var) / sum(apply(pco5[tree5$tip.label, ], 2, var)))) / max((apply(pco5[tree5$tip.label, ], 2, var) / sum(apply(pco5[tree5$tip.label, ], 2, var))) - min(apply(pco5[tree5$tip.label, ], 2, var) / sum(apply(pco5, 2, var))))
Scree6 <- ((apply(pco6, 2, var) / sum(apply(pco6, 2, var))) - min(apply(pco6, 2, var) / sum(apply(pco6, 2, var)))) / max((apply(pco6, 2, var) / sum(apply(pco6, 2, var))) - min(apply(pco6, 2, var) / sum(apply(pco6, 2, var))))

# Plot normalised scree values on a single plot:
plot(x = 1:ncol(pco1) / ncol(pco1), y = Scree1, type = "l", xlab = "Proportional ordination axes", ylab = "Proportional variance explained", col = rgb(0, 1, 1, 1), lwd = 2, ylim = c(0, 1))
points(x = 1:ncol(pco3) / ncol(pco3), y = Scree3, type = "l", col = rgb(1, 1, 0, 1), lwd = 2)
points(x = 1:ncol(pco2) / ncol(pco2), y = Scree2, type = "l", col = rgb(1, 0, 0, 1), lwd = 2)
points(x = 1:ncol(pco4) / ncol(pco4), y = Scree4, type = "l", col = rgb(0, 1, 0, 1), lwd = 2)
points(x = 1:ncol(pco5) / ncol(pco5), y = Scree5, type = "l", col = rgb(0, 0, 1, 1), lwd = 2)
points(x = 1:ncol(pco6) / ncol(pco6), y = Scree6, type = "l", col = rgb(1, 0, 1, 1), lwd = 2)
legend(x = 0.7, y = 1, legend = c("Pre-OASE1", "Pre-OASE2", "Pre-OASE3", "Pre-OASE4", "Post-OASE", "Phylospace"), col = c(rgb(0, 1, 1, 1), rgb(1, 1, 0, 1), rgb(1, 0, 0, 1), rgb(0, 1, 0, 1), rgb(0, 0, 1, 1), rgb(1, 0, 1, 1)), lwd = 3)

# Get edge from-to values for each spaces' tree:
EdgeToEdge1 <- tree1$edge
EdgeToEdge2 <- tree2$edge
EdgeToEdge3 <- tree3$edge
EdgeToEdge4 <- tree4$edge
EdgeToEdge5 <- tree5$edge
EdgeToEdge6 <- tree6$edge

# Update with tip names, not numbers:
EdgeToEdge1[match(1:Ntip(tree1), EdgeToEdge1[, 2]), 2] <- tree1$tip.label
EdgeToEdge2[match(1:Ntip(tree2), EdgeToEdge2[, 2]), 2] <- tree2$tip.label
EdgeToEdge3[match(1:Ntip(tree3), EdgeToEdge3[, 2]), 2] <- tree3$tip.label
EdgeToEdge4[match(1:Ntip(tree4), EdgeToEdge4[, 2]), 2] <- tree4$tip.label
EdgeToEdge5[match(1:Ntip(tree5), EdgeToEdge5[, 2]), 2] <- tree5$tip.label
EdgeToEdge6[match(1:Ntip(tree6), EdgeToEdge6[, 2]), 2] <- tree6$tip.label

# Create new space trees (will use edge lengths to store distace in space):
PCOTree1 <- tree1
PCOTree2 <- tree2
PCOTree3 <- tree3
PCOTree4 <- tree4
PCOTree5 <- tree5
PCOTree6 <- tree6

# Update space trees with branch lengths reflecting distance in space:
for(j in 1:nrow(EdgeToEdge1)) PCOTree1$edge.length[j] <- sqrt(sum(apply(cbind(pco1[which(rownames(pco1) == EdgeToEdge1[j, 1]), ], pco1[which(rownames(pco1) == EdgeToEdge1[j, 2]), ]), 1, diff) ^ 2))
for(j in 1:nrow(EdgeToEdge2)) PCOTree2$edge.length[j] <- sqrt(sum(apply(cbind(pco2[which(rownames(pco2) == EdgeToEdge2[j, 1]), ], pco2[which(rownames(pco2) == EdgeToEdge2[j, 2]), ]), 1, diff) ^ 2))
for(j in 1:nrow(EdgeToEdge3)) PCOTree3$edge.length[j] <- sqrt(sum(apply(cbind(pco3[which(rownames(pco3) == EdgeToEdge3[j, 1]), ], pco3[which(rownames(pco3) == EdgeToEdge3[j, 2]), ]), 1, diff) ^ 2))
for(j in 1:nrow(EdgeToEdge4)) PCOTree4$edge.length[j] <- sqrt(sum(apply(cbind(pco4[which(rownames(pco4) == EdgeToEdge4[j, 1]), ], pco4[which(rownames(pco4) == EdgeToEdge4[j, 2]), ]), 1, diff) ^ 2))
for(j in 1:nrow(EdgeToEdge5)) PCOTree5$edge.length[j] <- sqrt(sum(apply(cbind(pco5[which(rownames(pco5) == EdgeToEdge5[j, 1]), ], pco5[which(rownames(pco5) == EdgeToEdge5[j, 2]), ]), 1, diff) ^ 2))
for(j in 1:nrow(EdgeToEdge6)) PCOTree6$edge.length[j] <- sqrt(sum(apply(cbind(pco6[which(rownames(pco6) == EdgeToEdge6[j, 1]), ], pco6[which(rownames(pco6) == EdgeToEdge6[j, 2]), ]), 1, diff) ^ 2))

# Do "rate" branch duration and length bivariate plots:
#par(mfrow = c(2, 3))
plot(x = tree1$edge.length, y = PCOTree1$edge.length, pch = 20, col = "red", cex = 1.5, log = "x", xlab = "Branch duration", ylab = "Branch length")
plot(x = tree3$edge.length, y = PCOTree3$edge.length, pch = 20, col = "red", cex = 1.5, log = "x", xlab = "Branch duration", ylab = "Branch length")
plot(x = tree2$edge.length, y = PCOTree2$edge.length, pch = 20, col = "red", cex = 1.5, log = "x", xlab = "Branch duration", ylab = "Branch length")
plot(x = tree4$edge.length, y = PCOTree4$edge.length, pch = 20, col = "red", cex = 1.5, log = "x", xlab = "Branch duration", ylab = "Branch length")
plot(x = tree5$edge.length, y = PCOTree5$edge.length, pch = 20, col = "red", cex = 1.5, log = "x", xlab = "Branch duration", ylab = "Branch length")
plot(x = tree6$edge.length, y = PCOTree6$edge.length, pch = 20, col = "red", cex = 1.5, log = "x", xlab = "Branch duration", ylab = "Branch length")

# Rate "correlation"s:
cor.test(x = tree1$edge.length, y = PCOTree1$edge.length, method = "kendall")$estimate
cor.test(x = tree3$edge.length, y = PCOTree3$edge.length, method = "kendall")$estimate
cor.test(x = tree2$edge.length, y = PCOTree2$edge.length, method = "kendall")$estimate
cor.test(x = tree4$edge.length, y = PCOTree4$edge.length, method = "kendall")$estimate
cor.test(x = tree5$edge.length, y = PCOTree5$edge.length, method = "kendall")$estimate
cor.test(x = tree6$edge.length, y = PCOTree6$edge.length, method = "kendall")$estimate

# Function to generate the D_tip and D_max values used in Stayton (2015) C1 and C2 metrics:
StaytonConvergence <- function(PCOMatrix, tree) {
  # Check for divide by zero problem? What output should these even have?
  # CHERRIES! (Includes I guess polytomies?)
  PCODistanceMatrix <- as.matrix(dist(PCOMatrix))
  LineageDistances <- TaxonPairs <- matrix(nrow = 0, ncol = 2)
  for(i in 1:(Ntip(tree) - 1)) {
    for(j in (i + 1):Ntip(tree)) {
      TaxonPairs <- rbind(TaxonPairs, c(tree$tip.label[i], tree$tip.label[j]))
    }
  }
  for(i in 1:nrow(TaxonPairs)) {
    CurrentMRCA <- FindAncestor(descs = TaxonPairs[i, ], tree = tree)
    LineageNodes <- CurrentNodes <- c(which(tree$tip.label == TaxonPairs[i, 1]), which(tree$tip.label == TaxonPairs[i, 2]))
    AncestorNodes <- c(tree$edge[which(tree$edge[, 2] == CurrentNodes[1]), 1], tree$edge[which(tree$edge[, 2] == CurrentNodes[2]), 1])
    while(length(which(AncestorNodes == CurrentMRCA)) < 2) {
      CurrentNodes[which(AncestorNodes != CurrentMRCA)] <- AncestorNodes[which(AncestorNodes != CurrentMRCA)]
      AncestorNodes <- c(tree$edge[which(tree$edge[, 2] == CurrentNodes[1]), 1], tree$edge[which(tree$edge[, 2] == CurrentNodes[2]), 1])
      LineageNodes <- c(LineageNodes, CurrentNodes)
    }
    LineageNodes <- c(TaxonPairs[i, ], setdiff(unique(LineageNodes), 1:Ntip(tree)))
    CurrentRows <- match(LineageNodes, rownames(PCODistanceMatrix))
    D_max <- max(PCODistanceMatrix[CurrentRows, CurrentRows])
    D_tip <- PCODistanceMatrix[CurrentRows[1], CurrentRows[2]]
    LineageDistances <- rbind(LineageDistances, c(D_tip, D_max))
  }
  return(LineageDistances)
}

# Get C1 convergence values for each pairwise tip comparison:
Convergence1 <- StaytonConvergence(PCOMatrix = pco1, tree = tree1)
Convergence3 <- StaytonConvergence(PCOMatrix = pco3, tree = tree3)
Convergence2 <- StaytonConvergence(PCOMatrix = pco2, tree = tree2)
Convergence4 <- StaytonConvergence(PCOMatrix = pco4, tree = tree4)
Convergence5 <- StaytonConvergence(PCOMatrix = pco5, tree = tree5)
Convergence6 <- StaytonConvergence(PCOMatrix = pco6, tree = tree6)

# Plot convergence (C1) histograms:
#par(mfrow = c(2, 3))
hist(1 - (Convergence1[, 1] / Convergence1[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), xlab = "C1", border = 0, col = "grey", main = "Pre-OASE1")
hist(1 - (Convergence3[, 1] / Convergence3[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), xlab = "C1", border = 0, col = "grey", main = "Pre-OASE2")
hist(1 - (Convergence2[, 1] / Convergence2[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), xlab = "C1", border = 0, col = "grey", main = "Pre-OASE3")
hist(1 - (Convergence4[, 1] / Convergence4[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), xlab = "C1", border = 0, col = "grey", main = "Pre-OASE4")
hist(1 - (Convergence5[, 1] / Convergence5[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), xlab = "C1", border = 0, col = "grey", main = "Post-OASE")
hist(1 - (Convergence6[, 1] / Convergence6[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), xlab = "C1", border = 0, col = "grey", main = "Phylospace")

# Alternative C2 plots:
#par(mfrow = c(2, 3))
#hist(Convergence1[, 2] - Convergence1[, 1], breaks = seq(from = 0, to = max(Convergence1[, 2]), length.out = 50), xlab = "C2", border = 0, col = "grey", main = "Pre-OASE1")
#hist(Convergence3[, 2] - Convergence3[, 1], breaks = seq(from = 0, to = max(Convergence2[, 2]), length.out = 50), xlab = "C2", border = 0, col = "grey", main = "Pre-OASE2")
#hist(Convergence2[, 2] - Convergence2[, 1], breaks = seq(from = 0, to = max(Convergence3[, 2]), length.out = 50), xlab = "C2", border = 0, col = "grey", main = "Pre-OASE3")
#hist(Convergence4[, 2] - Convergence4[, 1], breaks = seq(from = 0, to = max(Convergence4[, 2]), length.out = 50), xlab = "C2", border = 0, col = "grey", main = "Pre-OASE4")
#hist(Convergence5[, 2] - Convergence5[, 1], breaks = seq(from = 0, to = max(Convergence5[, 2]), length.out = 50), xlab = "C2", border = 0, col = "grey", main = "Post-OASE")
#hist(Convergence6[, 2] - Convergence6[, 1], breaks = seq(from = 0, to = max(Convergence6[, 2]), length.out = 50), xlab = "C2", border = 0, col = "grey", main = "Phylospace")

# Mean pairwise C1 (covergence) for each ordination:
mean(1 - (Convergence1[, 1] / Convergence1[, 2]))
mean(1 - (Convergence3[, 1] / Convergence3[, 2]))
mean(1 - (Convergence2[, 1] / Convergence2[, 2]))
mean(1 - (Convergence4[, 1] / Convergence4[, 2]))
mean(1 - (Convergence5[, 1] / Convergence5[, 2]))
mean(1 - (Convergence6[, 1] / Convergence6[, 2]))

# Distance correlation plots:
plot(x = dist(pco1), y = as.dist(dist.nodes(tree1)), pch = 20, col = "red", cex = 0.5)
plot(x = dist(pco3), y = as.dist(dist.nodes(tree3)), pch = 20, col = "red", cex = 0.5)
plot(x = dist(pco2), y = as.dist(dist.nodes(tree2)), pch = 20, col = "red", cex = 0.5)
plot(x = dist(pco4), y = as.dist(dist.nodes(tree4)), pch = 20, col = "red", cex = 0.5)
plot(x = dist(pco5), y = as.dist(dist.nodes(tree5)), pch = 20, col = "red", cex = 0.5)
plot(x = dist(pco6), y = as.dist(dist.nodes(tree6)), pch = 20, col = "red", cex = 0.5)

# Stop plotting to PDF:
dev.off()

# Plot proto Figure 4 to PDF:
pdf("~/Documents/Publications/Submitted/Disparity and rates review - Solo/Dryad upload/Figure_4.pdf", width = 7, height = 10, useDingbats = FALSE)

# Bottom, left, top, right:
par(mfrow = c(6, 4), mar = c(2, 2, 0, 0), bty = "o")

# Plot first row (pre-OASE1):
plot(1:ncol(pco1), apply(pco1, 2, var) / sum(apply(pco1, 2, var)) * 100, type = "l", main = "", xlab = "", ylab = "", axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
plot(pco1[, pco_axis_1], pco1[, pco_axis_2], type = "n", xlab = "", ylab = "", main = "", asp = 1, axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
for(j in 1:nrow(tree1$edge)) {
		nodes <- tree1$edge[j, ]
    if(any(nodes <= Ntip(tree1))) nodes[nodes <= Ntip(tree1)] <- tree1$tip.label[nodes[nodes <= Ntip(tree1)]]
    lines(x = c(pco1[nodes[1], pco_axis_1], pco1[nodes[2], pco_axis_1]), y = c(pco1[nodes[1], pco_axis_2], pco1[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco1[, pco_axis_1], pco1[, pco_axis_2], pch = 20, col = "red")
meanrate <- sum(PCOTree1$edge.length) / sum(tree1$edge.length)
NewX <- seq(from = min(tree1$edge.length) * 0.8, to = max(tree1$edge.length) * 1.2, length.out = 100)
plot(x = tree3$edge.length, y = PCOTree3$edge.length, type = "n", cex = 1.5, log = "x", xlab = "", ylab = "", axes = FALSE)
for(i in 100:1) polygon(x = c(NewX, rev(NewX)), y = c(NewX * meanrate * i, rev(NewX * meanrate * (1 / i))), border = 0, col = rev(magma(100))[i])
points(x = tree1$edge.length, y = PCOTree1$edge.length, pch = 21, bg = "black", cex = 0.5)
lines(x = NewX, y = NewX * meanrate, lty = 5, lwd = 2, col = "red")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
hist(1 - (Convergence1[, 1] / Convergence1[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), border = 0, col = "grey", main = "", axes = FALSE, xlab = "", ylab = "")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()

# Plot second row (pre-OASE2):
plot(1:ncol(pco3), apply(pco3, 2, var) / sum(apply(pco3, 2, var)) * 100, type = "l", main = "", xlab = "", ylab = "", axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
plot(pco3[, pco_axis_1], pco3[, pco_axis_2], type = "n", xlab = "", ylab = "", main = "", asp = 1, axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
for(j in 1:nrow(tree3$edge)) {
		nodes <- tree3$edge[j, ]
    if(any(nodes <= Ntip(tree3))) nodes[nodes <= Ntip(tree3)] <- tree3$tip.label[nodes[nodes <= Ntip(tree3)]]
    lines(x = c(pco3[nodes[1], pco_axis_1], pco3[nodes[2], pco_axis_1]), y = c(pco3[nodes[1], pco_axis_2], pco3[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco3[, pco_axis_1], pco3[, pco_axis_2], pch = 20, col = "red")
meanrate <- sum(PCOTree3$edge.length) / sum(tree3$edge.length)
NewX <- seq(from = min(tree3$edge.length) * 0.8, to = max(tree3$edge.length) * 1.2, length.out = 100)
plot(x = tree3$edge.length, y = PCOTree3$edge.length, type = "n", cex = 1.5, log = "x", xlab = "", ylab = "", axes = FALSE)
for(i in 100:1) polygon(x = c(NewX, rev(NewX)), y = c(NewX * meanrate * i, rev(NewX * meanrate * (1 / i))), border = 0, col = rev(magma(100))[i])
points(x = tree3$edge.length, y = PCOTree3$edge.length, pch = 21, bg = "black", cex = 0.5)
lines(x = NewX, y = NewX * meanrate, lty = 5, lwd = 2, col = "red")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
hist(1 - (Convergence3[, 1] / Convergence3[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), border = 0, col = "grey", main = "", axes = FALSE, xlab = "", ylab = "")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()

# Plot third row (pre-OASE3):
plot(1:ncol(pco2), apply(pco2, 2, var) / sum(apply(pco2, 2, var)) * 100, type = "l", main = "", xlab = "", ylab = "", axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
plot(pco2[, pco_axis_1], pco2[, pco_axis_2], type = "n", xlab = "", ylab = "", main = "", asp = 1, axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
for(j in 1:nrow(tree2$edge)) {
		nodes <- tree2$edge[j, ]
    if(any(nodes <= Ntip(tree2))) nodes[nodes <= Ntip(tree2)] <- tree2$tip.label[nodes[nodes <= Ntip(tree2)]]
    lines(x = c(pco2[nodes[1], pco_axis_1], pco2[nodes[2], pco_axis_1]), y = c(pco2[nodes[1], pco_axis_2], pco2[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco2[, pco_axis_1], pco2[, pco_axis_2], pch = 20, col = "red")
meanrate <- sum(PCOTree2$edge.length) / sum(tree2$edge.length)
NewX <- seq(from = min(tree2$edge.length) * 0.8, to = max(tree2$edge.length) * 1.2, length.out = 100)
plot(x = tree2$edge.length, y = PCOTree2$edge.length, type = "n", cex = 1.5, log = "x", xlab = "", ylab = "", axes = FALSE)
for(i in 100:1) polygon(x = c(NewX, rev(NewX)), y = c(NewX * meanrate * i, rev(NewX * meanrate * (1 / i))), border = 0, col = rev(magma(100))[i])
points(x = tree2$edge.length, y = PCOTree2$edge.length, pch = 21, bg = "black", cex = 0.5)
lines(x = NewX, y = NewX * meanrate, lty = 5, lwd = 2, col = "red")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
hist(1 - (Convergence2[, 1] / Convergence2[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), border = 0, col = "grey", main = "", axes = FALSE, xlab = "", ylab = "")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()

# Plot fourth row (pre-OASE4):
plot(1:ncol(pco4), apply(pco4, 2, var) / sum(apply(pco4, 2, var)) * 100, type = "l", main = "", xlab = "", ylab = "", axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
plot(pco4[, pco_axis_1], pco4[, pco_axis_2], type = "n", xlab = "", ylab = "", main = "", asp = 1, axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
for(j in 1:nrow(tree4$edge)) {
		nodes <- tree4$edge[j, ]
    if(any(nodes <= Ntip(tree4))) nodes[nodes <= Ntip(tree4)] <- tree4$tip.label[nodes[nodes <= Ntip(tree4)]]
    lines(x = c(pco4[nodes[1], pco_axis_1], pco4[nodes[2], pco_axis_1]), y = c(pco4[nodes[1], pco_axis_2], pco4[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco4[, pco_axis_1], pco4[, pco_axis_2], pch = 20, col = "red")
meanrate <- sum(PCOTree4$edge.length) / sum(tree4$edge.length)
NewX <- seq(from = min(tree4$edge.length) * 0.8, to = max(tree4$edge.length) * 1.2, length.out = 100)
plot(x = tree4$edge.length, y = PCOTree4$edge.length, type = "n", cex = 1.5, log = "x", xlab = "", ylab = "", axes = FALSE)
for(i in 100:1) polygon(x = c(NewX, rev(NewX)), y = c(NewX * meanrate * i, rev(NewX * meanrate * (1 / i))), border = 0, col = rev(magma(100))[i])
points(x = tree4$edge.length, y = PCOTree4$edge.length, pch = 21, bg = "black", cex = 0.5)
lines(x = NewX, y = NewX * meanrate, lty = 5, lwd = 2, col = "red")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
hist(1 - (Convergence4[, 1] / Convergence4[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), border = 0, col = "grey", main = "", axes = FALSE, xlab = "", ylab = "")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()

# Plot fifth row (post-OASE):
plot(1:ncol(pco5), apply(pco5[1:Ntip(tree5), ], 2, var) / sum(apply(pco5[1:Ntip(tree5), ], 2, var)) * 100, type = "l", main = "", xlab = "", ylab = "", axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
plot(pco5[, pco_axis_1], pco5[, pco_axis_2], type = "n", xlab = "", ylab = "", main = "", asp = 1, axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
for(j in 1:nrow(tree5$edge)) {
		nodes <- tree5$edge[j, ]
    if(any(nodes <= Ntip(tree5))) nodes[nodes <= Ntip(tree5)] <- tree5$tip.label[nodes[nodes <= Ntip(tree5)]]
    lines(x = c(pco5[nodes[1], pco_axis_1], pco5[nodes[2], pco_axis_1]), y = c(pco5[nodes[1], pco_axis_2], pco5[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco5[, pco_axis_1], pco5[, pco_axis_2], pch = 20, col = "red")
meanrate <- sum(PCOTree5$edge.length) / sum(tree5$edge.length)
NewX <- seq(from = min(tree5$edge.length) * 0.8, to = max(tree5$edge.length) * 1.2, length.out = 100)
plot(x = tree5$edge.length, y = PCOTree5$edge.length, type = "n", cex = 1.5, log = "x", xlab = "", ylab = "", axes = FALSE)
for(i in 100:1) polygon(x = c(NewX, rev(NewX)), y = c(NewX * meanrate * i, rev(NewX * meanrate * (1 / i))), border = 0, col = rev(magma(100))[i])
points(x = tree5$edge.length, y = PCOTree5$edge.length, pch = 21, bg = "black", cex = 0.5)
lines(x = NewX, y = NewX * meanrate, lty = 5, lwd = 2, col = "red")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
hist(1 - (Convergence5[, 1] / Convergence5[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), border = 0, col = "grey", main = "", axes = FALSE, xlab = "", ylab = "")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()

# Plot bottom row (phylospace):
plot(1:ncol(pco6), apply(pco6, 2, var) / sum(apply(pco6, 2, var)) * 100, type = "l", main = "", xlab = "", ylab = "", axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
plot(pco6[, pco_axis_1], pco6[, pco_axis_2], type = "n", xlab = "", ylab = "", main = "", asp = 1, axes = FALSE)
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
for(j in 1:nrow(tree6$edge)) {
		nodes <- tree6$edge[j, ]
    if(any(nodes <= Ntip(tree6))) nodes[nodes <= Ntip(tree6)] <- tree6$tip.label[nodes[nodes <= Ntip(tree6)]]
    lines(x = c(pco6[nodes[1], pco_axis_1], pco6[nodes[2], pco_axis_1]), y = c(pco6[nodes[1], pco_axis_2], pco6[nodes[2], pco_axis_2]), col = "grey", lwd = 2)
}
points(pco6[, pco_axis_1], pco6[, pco_axis_2], pch = 20, col = "red")
meanrate <- sum(PCOTree6$edge.length) / sum(tree6$edge.length)
NewX <- seq(from = min(tree6$edge.length) * 0.8, to = max(tree6$edge.length) * 1.2, length.out = 100)
plot(x = tree6$edge.length, y = PCOTree6$edge.length, type = "n", cex = 1.5, log = "x", xlab = "", ylab = "", axes = FALSE)
for(i in 100:1) polygon(x = c(NewX, rev(NewX)), y = c(NewX * meanrate * i, rev(NewX * meanrate * (1 / i))), border = 0, col = rev(magma(100))[i])
points(x = tree6$edge.length, y = PCOTree6$edge.length, pch = 21, bg = "black", cex = 0.5)
lines(x = NewX, y = NewX * meanrate, lty = 5, lwd = 2, col = "red")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()
hist(1 - (Convergence6[, 1] / Convergence6[, 2]), breaks = seq(from = 0, to = 0.4, by = 0.025), border = 0, col = "grey", main = "", axes = FALSE, xlab = "", ylab = "")
axis(side = 1, padj = -2, tck = -0.01, cex.axis = 0.8)
axis(side = 2, padj = 1.5, tck = -0.01, cex.axis = 0.8)
box()

# Stop plotting to PDF:
dev.off()
